@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 import django
 from .views import (markdownfy_view,
                     markdown_imgur_uploader,
+                    markdown_uploader,
                     markdown_search_user)
 
 
@@ -11,7 +12,7 @@ if django.VERSION >= (2, 0):
     from django.urls import path
     urlpatterns = [
         path('markdownify/', markdownfy_view, name='martor_markdownfy'),
-        path('uploader/', markdown_imgur_uploader, name='imgur_uploader'),
+        path('local_uploader/', markdown_uploader, name='local_uploader'),
         path('search-user/', markdown_search_user, name='search_user_json'),
     ]
 else:
